from django.test import TestCase

from guardian.shortcuts import assign_perm
from guardian.utils import get_anonymous_user

from pgp import models

class CorsHeadersTestCase(TestCase):
    """Check that responses have appropriate CORS headers"""

    def setUp(self):
        self.toykey = models.PublicKey.objects.create(
            email="frank@sauerburger.com",
            keyid="123456789",
        )
        anonymous = get_anonymous_user()
        assign_perm('view_publickey', anonymous, self.toykey)

    def test_policy(self):
        """Check that the policy file has CORS headers"""
        response = self.client.get('/pks/lookup?op=get&search=789')
        self.assertEqual(response.status_code, 200)
        self.assertEqual(response["access-control-allow-origin"], "*")

class CaseSensitivityTestCase(TestCase):
    """Check that HKP access is case-insensitive"""

    def setUp(self):
        self.toykey = models.PublicKey.objects.create(
            email="frank@sauerburger.com",
            keyid="123456789abcd",
        )
        anonymous = get_anonymous_user()
        assign_perm('view_publickey', anonymous, self.toykey)

    def test_lower(self):
        """Check that lower case string can be used to lookup a key"""
        response = self.client.get('/pks/lookup?op=get&search=abcd')
        self.assertEqual(response.status_code, 200)

    def test_upper(self):
        """Check that upper case string can be used to lookup a key"""
        response = self.client.get('/pks/lookup?op=get&search=ABCD')
        self.assertEqual(response.status_code, 200)

    def test_mixed(self):
        """Check that the mixed case can be used to lookup a key"""
        response = self.client.get('/pks/lookup?op=get&search=abCD')
        self.assertEqual(response.status_code, 200)
