from django.test import TestCase
from .models import lower, PublicKey
from . import zbase32

class LowerTestCase(TestCase):
    """Test the ascii lower for WKD"""

    def test_ascii(self):
        """Check that ascii chars are mapped to lower-case"""
        self.assertEqual(lower("ABCDEF"), "abcdef")
        self.assertEqual(lower("abcdef"), "abcdef")

    def test_non_alpha(self):
        """Check that non-alphabet, ascii chars are unchanged"""
        self.assertEqual(lower("123.+=?"), "123.+=?")

    def test_non_ascii(self):
        """Check that non-ascii chars are unchanged"""
        self.assertEqual(lower("ÄäÉé"), "ÄäÉé")

class WkdLocalPartNecode(TestCase):
    """Test the encoding of the local part for WKD"""

    def test_ascii(self):
        """Check that ascii chars are encoded correctly"""
        local = PublicKey.encode_wkd_local("Joe.Doe@domain")
        self.assertEqual(local, "iy9q119eutrkn8s1mk4r39qejnbu3n5q")

class ZBase32TestCase(TestCase):
    """Test the implementation of zbase32"""
    def test_encode(self):
        """Check that test string is encoded corretly"""
        encoded = zbase32.encode(b"hello, world\n")
        self.assertEqual(encoded, b"pb1sa5dxfoo8q551pt1yw===")

    def test_decode(self):
        """Check that the string is decoded to test string"""
        decoded = zbase32.decode(b"pb1sa5dxfoo8q551pt1yw===")
        self.assertEqual(decoded, b"hello, world\n")

    def test_roundtrip(self):
        """Check that encoding and decoding is the indentity map"""
        string = b"AI4$!Oi[^F9YOMg&q>0BC%Jz+NshpK:c"
        encoded = zbase32.encode(string)
        decoded = zbase32.decode(encoded)
        self.assertEqual(string, decoded)
